==> wikindx-3.4.3.tbz: www/wikindx/languages/en/SUCCESS.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

TheWIKINDX Team 2004
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
* SUCCESS_en class (English)
* NOTE TO TRANSLATORS:  1/  '###' appearing anywhere in an array value will be replaced by text supplied by the core WIKINDX code.
*				Do not remove it and do not put space around it.
*			2/  Do not change the key (the first part) of an array element.
*			3/  Ensure that each array element value is enclosed in double quotes "..." and is followed by a comma "...",
*			4/  Both the class name and the constructor name should be changed to match the (case-sensitive) name of 
*				the folder your language files are in.  For example, if you are supplying a Klingon translation and 
*				your languages/ folder is languages/kn/, the class and constructor name for the file SUCCESS.php 
*				must both be SUCCESS_kn.
*
* NOTE TO DEVELOPERS:  1/ Any comments not preceeded by '//' will be ignored by the localization module.
*				2/  All comments should be on one line (no line breaks) and must start at the beginning of the line for the localization module to work.
*				3/  Comments must be of the form '// paraphrases This is the comment' where 'paraphrases' is the exact array key that the comment refers to.
*****/
class SUCCESS_en
{
// Constructor
	function SUCCESS_en()
	{
	}
// English success messages
	function loadArrays()
	{
		return array(
				"notes"		=>	"Successfully###note",
				"quotes"	=>	"Successfully###quote",
				"paraphrases"	=>	"Successfully###paraphrase",
				"musings"	=>	"Successfully###musing",
				"abstract"	=>	"Successfully###abstract",
				"config"	=>	"Successfully configured WIKINDX",
// MG - removed for v2.2
//				"convert"	=>	"Successfully converted v1 resources to v2###. It is recommended
//					that you do not attempt to convert the same v1 database again and that you
//					turn off the DB Convert option in the Admin|Configure page to remove the
//					'Convert DB' item from the menu and the temptation to click it again.",
				"resource"	=>	"Successfully###resource",
				"category"		=>	"Successfully###category(s)",
				"creator"	=>	"Successfully edited creator",
				"publisher"	=>	"Successfully edited publisher",
				"collection"	=>	"Successfully edited collection",
				"bibtexImport"	=>	"Successfully uploaded BibTeX bibliography",
				"endnoteImport"	=>	"Successfully uploaded Endnote XML bibliography",
				"keyword"	=>	"Successfully edited keyword",
				"user"		=>	"Successfully###user(s)",
				"registerEmail"	=>	"An email has been sent to you with further instructions",
				"bibliography"	=>	"Successfully###bibliography",
				"addBib"	=>	"Successfully added item to bibliography",
				"deleteFromBib"	=>	"Successfully deleted item(s) from bibliography",
				"notify"	=>	"Successfully set email notification",
				"news"		=>	"Successfully###news",
				"style"		=>	"Successfully###bibliographic style",
				"field"		=>	"Successfully###custom database field",
				"attach"	=>	"Successfully###attachment",
				"addResourceToCategory"	=>	"Successfully added resources to category(s)",
				"addResourceToKeyword"	=>	"Successfully added resources to keyword(s)",
				"convertType"	=>	"Successfully converted resource type",
				"bookmark"	=>	"Successfully added bookmark",
// for saving papers etc.
				"saveWP"	=>	"Successfully saved paper",
				"deleteWp"	=>	"Successfully deleted paper(s)",
				"importWp"	=>	"Successfully imported paper",
				"keywordMerge"	=>	"Successfully merged keywords",
				"basketAdd"	=>	"Successfully added resource to basket",
				"basketRemove"	=>	"Successfully removed resource from basket",
				"basketDelete"	=>	"Successfully deleted basket",
				"forgetUpdate"	=>	"Successfully updated the forgotten password system",
				"maturityIndex"	=>	"Successfully set the maturity index",
		);
	}
}
?>

==> wikindx-3.8.2.tbz: www/wikindx/languages/en/SUCCESS.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

TheWIKINDX Team 2007
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
* SUCCESS_en class (English)
* NOTE TO TRANSLATORS:  1/  '###' appearing anywhere in an array value will be replaced by text supplied by the core WIKINDX code.
*				Do not remove it and do not put space around it.
*			2/  Do not change the key (the first part) of an array element.
*			3/  Ensure that each array element value is enclosed in double quotes "..." and is followed by a comma "...",
*			4/  Both the class name and the constructor name should be changed to match the (case-sensitive) name of 
*				the folder your language files are in.  For example, if you are supplying a Klingon translation and 
*				your languages/ folder is languages/kn/, the class and constructor name for the file SUCCESS.php 
*				must both be SUCCESS_kn.
*
* NOTE TO DEVELOPERS:  1/ Any comments not preceeded by '///' at the start of the line will be ignored by the localization module.
*				2/  All comments should be on one line (no line breaks) and must start at the beginning of the line for the localization module to work.
*				3/  Comments must be of the form '/// notes_ This array does this' where 'notes' is the array key that the comment refers to.
*****/
class SUCCESS_en
{
// Constructor
	function SUCCESS_en()
	{
	}
// English success messages
	function loadArrays()
	{
		return array(
// START__LOCALIZATION__MODULE__EDIT
/// notes_ '###' will be 'created', 'added', edited', 'deleted'....
				"notes"		=>	"Successfully###note",
				"categoryKeyword"		=>	"Successfully###categories and keywords",
				"quotes"	=>	"Successfully###quote",
				"paraphrases"	=>	"Successfully###paraphrase",
				"musings"	=>	"Successfully###musing",
				"abstract"	=>	"Successfully###abstract",
				"config"	=>	"Successfully configured WIKINDX",
// MG - removed for v2.2
//				"convert"	=>	"Successfully converted v1 resources to v2###. It is recommended
//					that you do not attempt to convert the same v1 database again and that you
//					turn off the DB Convert option in the Admin|Configure page to remove the
//					'Convert DB' item from the menu and the temptation to click it again.",
				"resource"	=>	"Successfully###resource",
				"category"		=>	"Successfully###category(s)",
				"creator"	=>	"Successfully edited creator",
				"publisher"	=>	"Successfully edited publisher",
				"collection"	=>	"Successfully edited collection",
				"bibtexImport"	=>	"Successfully uploaded BibTeX bibliography",
				"endnoteImport"	=>	"Successfully uploaded Endnote XML bibliography",
				"keyword"	=>	"Successfully edited keyword",
				"user"		=>	"Successfully###user(s)",
				"registerEmail"	=>	"An email has been sent to you with further instructions",
				"bibliography"	=>	"Successfully###bibliography",
				"addBib"	=>	"Successfully added item to bibliography",
				"deleteFromBib"	=>	"Successfully deleted item(s) from bibliography",
				"notify"	=>	"Successfully set email notification",
				"news"		=>	"Successfully###news",
				"style"		=>	"Successfully###bibliographic style",
				"field"		=>	"Successfully###custom database field",
				"attach"	=>	"Successfully###attachment",
				"addResourceToCategory"	=>	"Successfully added resources to category(s)",
				"addResourceToKeyword"	=>	"Successfully added resources to keyword(s)",
				"convertType"	=>	"Successfully converted resource type",
				"bookmark"	=>	"Successfully added bookmark",
				"bookmarkDelete"	=>	"Successfully deleted bookmark(s)",
/// saveWP_ For saving papers etc.
				"saveWP"	=>	"Successfully saved paper",
				"deleteWp"	=>	"Successfully deleted paper(s)",
				"importWp"	=>	"Successfully imported paper",
				"keywordMerge"	=>	"Successfully merged keywords",
				"basketAdd"	=>	"Successfully added resource to basket",
				"basketRemove"	=>	"Successfully removed resource from basket",
				"basketDelete"	=>	"Successfully deleted basket",
				"forgetUpdate"	=>	"Successfully updated the forgotten password system",
				"maturityIndex"	=>	"Successfully set the maturity index",
/// saveWikindxState_ For registered users, save the wikindx state for the next logon
				"saveWikindxState" => "WIKINDX state successfully saved",
				"group" => "Successfully###user group",
/// emailFriend_ User has emailed a firend a link to a resource
				"emailFriend" => "Successfully sent email",
				"creatorMerge"	=>	"Successfully merged creators",
				"registerRequest" => "Your registration request has been emailed to the WIKINDX administrator and you should receive an emailed response soon",
				"registerRequestManage"	=>	"Successfully managed registration requests.",
// END__LOCALIZATION__MODULE__EDIT
		);
	}
}
?>
